@@ -16,18 +16,18 @@
 ###########################################################
 
 ## Rocke type
-# .GSE.rocke.Rcpp <- function(x, mu0, S0, tol, maxiter, tol.scale, miter.scale, 
-	# miss.group.unique, miss.group.counts, tuning.const.group, gamma.const.group, print.step, bdp){
+.GSE.rocke.Rcpp <- function(x, mu0, S0, tol, maxiter, tol.scale, miter.scale, 
+	miss.group.unique, miss.group.counts, tuning.const.group, gamma.const.group, print.step, bdp){
 
-	# res <- tryCatch( .Call("GSE_Rocke", x, nrow(x), ncol(x), mu0, S0, 
-		# tol, maxiter, tol.scale, miter.scale, miss.group.unique, miss.group.counts, 
-		# tuning.const.group, gamma.const.group, print.step, bdp),
-		# "std::range_error" = function(e){
-		# conditionMessage( e ) } )
-	# # if( res$error_code == 1 ) warning("Estimated covariance matrix is not positive definite.")
-	# if(res$iter > maxiter) warning("Reached maximum number of iteration. No convergence is achieved.")
-	# res
-# }
+	res <- tryCatch( .Call("GSE_Rocke", x, nrow(x), ncol(x), mu0, S0, 
+		tol, maxiter, tol.scale, miter.scale, miss.group.unique, miss.group.counts, 
+		tuning.const.group, gamma.const.group, print.step, bdp),
+		"std::range_error" = function(e){
+		conditionMessage( e ) } )
+	# if( res$error_code == 1 ) warning("Estimated covariance matrix is not positive definite.")
+	if(res$iter > maxiter) warning("Reached maximum number of iteration. No convergence is achieved.")
+	res
+}
 
 #############################################################
 ## Tuning constant of rho for a given p 
@@ -126,51 +126,51 @@ tt
 }
 
 ## for rocke 
-# .rho.rocke.tune <- function(u){
+.rho.rocke.tune <- function(u){
 
-# uu <- c(
-# 0.498,1.4988,2.5371,3.5776,4.6135,
-# 5.6442,6.6745,7.6736,8.6679,9.664,
-# 10.6601,11.6568,12.6542,13.6528,14.649,
-# 15.6528,16.6481,17.6436,18.6504,19.644,
-# 20.6367,21.6414,22.6366,23.6376,24.645,
-# 25.6412,26.6328,27.636,28.6375,29.634,
-# 30.6342,31.6352,32.6337,33.6396,34.622,
-# 35.6364,36.6374,37.6314,38.6334,39.632,
-# 40.631,41.6346,42.6345,43.626,44.622,
-# 45.6366,46.624,47.6304,48.6276,49.625,
-# 50.6277,51.6256,52.6237,53.6328,54.626,
-# 55.6248,56.6295,57.6288,58.6165,59.622,
-# 60.6279,61.6156,62.6283,63.6224,64.6295,
-# 65.6238,66.6248,67.6192,68.6274,69.629,
-# 70.6237,71.6256,72.6277,73.63,74.625,
-# 75.62,76.6227,77.6178,78.6208,79.632,
-# 80.6193,81.631,82.6348,83.622,84.626,
-# 85.6216,86.6172,87.6304,88.6262,89.613,
-# 90.6269,91.6136,92.6187,93.6146,94.601,
-# 95.6256,96.6217,97.6178,98.6337,99.63,
-# 100.6263,101.6124,102.6086,103.6152,104.622,
-# 105.6184,106.6255,107.622,108.6185,109.615,
-# 110.6226,111.6192,112.6158,113.6124,114.609,
-# 115.6172,116.6256,117.6342,118.6073,119.616,
-# 120.6128,121.6218,122.6187,123.6156,124.625,
-# 125.622,126.6317,127.616,128.6001,129.623,
-# 130.6201,131.6172,132.6143,133.6114,134.622,
-# 135.6192,136.6164,137.6412,138.6247,139.622,
-# 140.6052,141.6024,142.6139,143.6112,144.623,
-# 145.635,146.6178,147.63,148.6275,149.61,
-# 150.6074,151.6048,152.6328,153.615,154.6125,
-# 155.61,156.6075,157.6208,158.6343,159.632,
-# 160.6297,161.6112,162.6414,163.6228,164.604,
-# 165.6182,166.6159,167.6136,168.6113,169.643,
-# 170.6238,171.6216,172.6194,173.6172,174.615,
-# 175.6128,176.6283,177.6262,178.6241,179.622,
-# 180.6018,181.5996,182.6157,183.6136,184.6115,
-# 185.6094,186.626,187.6052,188.622,189.62,
-# 190.6371,191.616,192.614,193.612,194.6295,
-# 195.608,196.6257,197.6238,198.6219,199.62
-# )
-# uu[u]
-# }
+uu <- c(
+0.498,1.4988,2.5371,3.5776,4.6135,
+5.6442,6.6745,7.6736,8.6679,9.664,
+10.6601,11.6568,12.6542,13.6528,14.649,
+15.6528,16.6481,17.6436,18.6504,19.644,
+20.6367,21.6414,22.6366,23.6376,24.645,
+25.6412,26.6328,27.636,28.6375,29.634,
+30.6342,31.6352,32.6337,33.6396,34.622,
+35.6364,36.6374,37.6314,38.6334,39.632,
+40.631,41.6346,42.6345,43.626,44.622,
+45.6366,46.624,47.6304,48.6276,49.625,
+50.6277,51.6256,52.6237,53.6328,54.626,
+55.6248,56.6295,57.6288,58.6165,59.622,
+60.6279,61.6156,62.6283,63.6224,64.6295,
+65.6238,66.6248,67.6192,68.6274,69.629,
+70.6237,71.6256,72.6277,73.63,74.625,
+75.62,76.6227,77.6178,78.6208,79.632,
+80.6193,81.631,82.6348,83.622,84.626,
+85.6216,86.6172,87.6304,88.6262,89.613,
+90.6269,91.6136,92.6187,93.6146,94.601,
+95.6256,96.6217,97.6178,98.6337,99.63,
+100.6263,101.6124,102.6086,103.6152,104.622,
+105.6184,106.6255,107.622,108.6185,109.615,
+110.6226,111.6192,112.6158,113.6124,114.609,
+115.6172,116.6256,117.6342,118.6073,119.616,
+120.6128,121.6218,122.6187,123.6156,124.625,
+125.622,126.6317,127.616,128.6001,129.623,
+130.6201,131.6172,132.6143,133.6114,134.622,
+135.6192,136.6164,137.6412,138.6247,139.622,
+140.6052,141.6024,142.6139,143.6112,144.623,
+145.635,146.6178,147.63,148.6275,149.61,
+150.6074,151.6048,152.6328,153.615,154.6125,
+155.61,156.6075,157.6208,158.6343,159.632,
+160.6297,161.6112,162.6414,163.6228,164.604,
+165.6182,166.6159,167.6136,168.6113,169.643,
+170.6238,171.6216,172.6194,173.6172,174.615,
+175.6128,176.6283,177.6262,178.6241,179.622,
+180.6018,181.5996,182.6157,183.6136,184.6115,
+185.6094,186.626,187.6052,188.622,189.62,
+190.6371,191.616,192.614,193.612,194.6295,
+195.608,196.6257,197.6238,198.6219,199.62
+)
+uu[u]
+}
 
 
